@@ -6,9 +6,12 @@ pub use types::*;
 #[cfg(target_os = "windows")]
 use backends::xinput::XInputBackend as Backend;
 
-#[cfg(not(any(target_os = "windows")))]
+#[cfg(not(any(target_os = "windows", target_os="android")))]
 use backends::gilrs::GilrsBackend as Backend;
 
+#[cfg(any(target_os="android"))]
+use backends::dummy::DummyBackend as Backend;
+
 pub struct GamepadEngine {
     backend: Box<dyn crate::backends::GamepadEngineBackend>,
 }
@@ -35,3 +38,6 @@ impl GamepadEngine {
         self.backend.gamepads_mut()
     }
 }
+
+unsafe impl Send for GamepadEngine {}
+unsafe impl Sync for GamepadEngine {}
\ No newline at end of file
